Groups for Business Baseline Report

### Secure Cloud Business Applications (SCuBA)

### Baseline Documents

# Groups for Business Baseline Report

Customer Name | Customer Domain | Customer ID | Report Date | Baseline Version | Tool Version
--- | --- | --- | --- | --- | ---
Cool Example Org | example.org | ABCDEFG | 06/26/2025 16:02:22 Pacific Daylight Time | 0.5 | v0.5.0

## GROUPS-1 External Group Access

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.GROUPS.1.1v0.5 | Group access from outside the organization SHALL be disabled unless explicitly granted by the group owner. | Pass | Shall | Requirement met in all OUs and groups.

## GROUPS-2 Adding External Members

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.GROUPS.2.1v0.5 | Group owners' ability to add external members to groups SHOULD be disabled unless necessary for agency mission fulfillment. | Pass | Should | Requirement met in all OUs and groups.

## GROUPS-3 Allowing Posting by External Members

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.GROUPS.3.1v0.5 | Group owners' ability to allow posting to a group by an external, non-group member SHOULD be disabled unless necessary for agency mission fulfillment. | Pass | Should | Requirement met in all OUs and groups.

## GROUPS-4 Group Creation

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.GROUPS.4.1v0.5 | Group creation SHOULD be restricted to admins within the organization unless necessary for agency mission fulfillment. | Pass | Should | Requirement met in all OUs and groups.

## GROUPS-5 Default Permissions for Viewing Conversations

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.GROUPS.5.1v0.5 | The default permission to view conversations SHOULD be set to All Group Members. | Pass | Should | Requirement met in all OUs and groups.

## GROUPS-6 Ability to Hide Groups from the Directory

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.GROUPS.6.1v0.5 | The Ability for Groups to be Hidden from the Directory SHALL be disabled. | Pass | Shall | Requirement met in all OUs and groups.